@@ -29,8 +29,7 @@ class TrfTokenizer(TrfAutoMixin, Pipe):
             [doc.text for doc in docs],
             add_special_tokens=True,
             return_tensors="pt",
-            return_input_lengths=True,
-            return_attention_masks=True,
+            return_attention_mask=True,
             return_special_tokens_mask=True,
             truncation=True,
             padding=True,
