@@ -54,6 +54,13 @@ def token_from_char_pos(doc: Doc, i: int) -> Token:
     return doc[bisect.bisect(token_idxs, i) - 1]
 
 
+def _get_covering_span(doc: Doc, i: int, j: int, **kwargs: Any) -> Span:
+    token_idxs = [t.idx for t in doc]
+    i = bisect.bisect(token_idxs, i) - 1
+    j = bisect.bisect_left(token_idxs, j)
+    return Span(doc, i, j, **kwargs)
+
+
 def destruct_token(doc: Doc, *char_pos: int) -> Doc:
     for i in char_pos:
         with doc.retokenize() as retokenizer:
@@ -64,7 +71,12 @@ def destruct_token(doc: Doc, *char_pos: int) -> Doc:
 
 
 def get_doc_char_span(
-    doc: Doc, i: int, j: int, destructive: bool = True, **kwargs
+    doc: Doc,
+    i: int,
+    j: int,
+    destructive: bool = True,
+    covering: bool = False,
+    **kwargs: Any,
 ) -> Optional[Span]:
     """Get Span from Doc with char position, similar to doc.char_span.
 
@@ -72,9 +84,12 @@ def get_doc_char_span(
         i: The index of the first character of the span
         j: The index of the first character after the span
         destructive: If True, tokens in [i,j) will be splitted and make sure to return span.
+        covering: If True, [i,j) will be adjusted to match the existing token boundaries. It precedes `destructive`.
         kwargs: passed to Doc.char_span
     """
     span = doc.char_span(i, j, **kwargs)
+    if not span and covering:
+        span = _get_covering_span(doc, i, j, **kwargs)
     if not span and destructive:
         destruct_token(doc, i, j)
         span = doc.char_span(i, j, **kwargs)
@@ -82,7 +97,7 @@ def get_doc_char_span(
 
 
 def get_doc_char_spans_list(
-    doc: Doc, spans: Iterable[Tuple[int, int]], destructive: bool = True, **kwargs
+    doc: Doc, spans: Iterable[Tuple[int, int]], destructive: bool = True, **kwargs: Any
 ) -> List[Span]:
     res = []
     for i, j in spans:
@@ -141,7 +156,7 @@ def get_labels(labels_or_path: Union[List[str], Pathlike]) -> List[str]:
     return cast(List[str], labels_or_path)
 
 
-def get_by_dotkey(d: dict, dotkey: str) -> Any:
+def get_by_dotkey(d: Any, dotkey: str) -> Any:
     assert dotkey
     keys = dotkey.split(".")
     cur = d
@@ -218,25 +233,25 @@ class SerializationMixin:
     serialization_fields: List[str] = []
     name: str
 
-    def from_bytes(self, bytes_data, **kwargs):
+    def from_bytes(self, bytes_data: bytes, **kwargs: Any):
         pkls = srsly.pickle_loads(bytes_data)
         for field in self.serialization_fields:
             setattr(self, field, pkls[field])
         return self
 
-    def to_bytes(self, **kwargs):
+    def to_bytes(self, **kwargs: Any):
         pkls = OrderedDict()
         for field in self.serialization_fields:
             pkls[field] = getattr(self, field, None)
         return srsly.pickle_dumps(pkls)
 
-    def from_disk(self, path: Path, **kwargs):
+    def from_disk(self, path: Path, **kwargs: Any):
         path.mkdir(exist_ok=True)
         with (path / "data.pkl").open("rb") as file_:
             data = file_.read()
         return self.from_bytes(data, **kwargs)
 
-    def to_disk(self, path: Path, **kwargs):
+    def to_disk(self, path: Path, **kwargs: Any):
         path.mkdir(exist_ok=True)
         data = self.to_bytes(**kwargs)
         with (path / "data.pkl").open("wb") as file_:
